.. :changelog:

History
-------


1.0.1 (2016-03-30)
++++++++++++++++++
* refactored tests
* fixes heroku example app

1.0.0 (2016-03-26)
++++++++++++++++++

* removed urls.W002 (changed URL for list)
* changed URL format for reverse (introduced namespace)
* dropped support for python 2.x

0.1.0 (2015-05-09)
++++++++++++++++++

* First release on PyPI.
